==> jc-1.4.0.tar.gz: java/nio/channels/Channels.h <==
// public final class java.nio.channels.Channels

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 10a71ae885a90895 java_nio_channels_Channels

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_Channels_H_
#define _JC_java_nio_channels_Channels_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_channels_WritableByteChannel$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_java_nio_channels_Channels$sub_refs	_jc_java_nio_channels_Channels$sub_refs;
typedef struct _jc_java_nio_channels_Channels$sub_nonrefs	_jc_java_nio_channels_Channels$sub_nonrefs;
typedef struct _jc_java_nio_channels_Channels$refs	_jc_java_nio_channels_Channels$refs;
typedef struct _jc_java_nio_channels_Channels$nonrefs	_jc_java_nio_channels_Channels$nonrefs;
typedef struct _jc_java_nio_channels_Channels$object	_jc_java_nio_channels_Channels$object;

typedef const struct _jc_java_nio_channels_Channels$vmethods	_jc_java_nio_channels_Channels$vmethods;
typedef const struct _jc_java_nio_channels_Channels$vtable	_jc_java_nio_channels_Channels$vtable;
typedef const struct _jc_java_nio_channels_Channels$vtype	_jc_java_nio_channels_Channels$vtype;

// Constructors
extern void _jc_java_nio_channels_Channels$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_Channels$object *);

// Static methods
extern struct _jc_object *_jc_java_nio_channels_Channels$method$newChannel$fbbca15d3c46a96a(_jc_env *, struct _jc_java_io_InputStream$object *);
extern struct _jc_object *_jc_java_nio_channels_Channels$method$newChannel$17120b72e13cdb59(_jc_env *, struct _jc_java_io_OutputStream$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_nio_channels_Channels$method$newInputStream$a1eabc144c1b09d2(_jc_env *, struct _jc_object *);
extern struct _jc_java_io_OutputStream$object *_jc_java_nio_channels_Channels$method$newOutputStream$eceb5d0d6e4ea2bb(_jc_env *, struct _jc_object *);
extern struct _jc_java_io_Reader$object *_jc_java_nio_channels_Channels$method$newReader$573210d7faf94df5(_jc_env *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_io_Reader$object *_jc_java_nio_channels_Channels$method$newReader$30328f08f38f28d8(_jc_env *, struct _jc_object *, struct _jc_java_nio_charset_CharsetDecoder$object *, jint);
extern struct _jc_java_io_Writer$object *_jc_java_nio_channels_Channels$method$newWriter$357027cb5c7e4756(_jc_env *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_io_Writer$object *_jc_java_nio_channels_Channels$method$newWriter$e122b7c65d603cb2(_jc_env *, struct _jc_object *, struct _jc_java_nio_charset_CharsetEncoder$object *, jint);

// Virtual methods structure
struct _jc_java_nio_channels_Channels$vmethods {
};

// Vtable
struct _jc_java_nio_channels_Channels$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Channels$vmethods	java_nio_channels_Channels;
};

// Vtype
struct _jc_java_nio_channels_Channels$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Channels$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Channels$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Channels$refs {
    _jc_java_nio_channels_Channels$sub_refs	java_nio_channels_Channels;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Channels$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Channels$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Channels$sub_nonrefs	java_nio_channels_Channels;
};

// Object instance structure
struct _jc_java_nio_channels_Channels$object {
	_jc_java_nio_channels_Channels$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Channels$vtype	*vtype;
	_jc_java_nio_channels_Channels$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Channels$vtype _jc_java_nio_channels_Channels$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Channels, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Channels$class_object;

#endif	/* _JC_java_nio_channels_Channels_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/Channels.h <==
// public final class java.nio.channels.Channels

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 10a71ae885a90895 java_nio_channels_Channels

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_Channels_H_
#define _JC_java_nio_channels_Channels_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_channels_WritableByteChannel$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_java_nio_channels_Channels$sub_refs	_jc_java_nio_channels_Channels$sub_refs;
typedef struct _jc_java_nio_channels_Channels$sub_nonrefs	_jc_java_nio_channels_Channels$sub_nonrefs;
typedef struct _jc_java_nio_channels_Channels$refs	_jc_java_nio_channels_Channels$refs;
typedef struct _jc_java_nio_channels_Channels$nonrefs	_jc_java_nio_channels_Channels$nonrefs;
typedef struct _jc_java_nio_channels_Channels$object	_jc_java_nio_channels_Channels$object;

typedef const struct _jc_java_nio_channels_Channels$vmethods	_jc_java_nio_channels_Channels$vmethods;
typedef const struct _jc_java_nio_channels_Channels$vtable	_jc_java_nio_channels_Channels$vtable;
typedef const struct _jc_java_nio_channels_Channels$vtype	_jc_java_nio_channels_Channels$vtype;

// Constructors
extern void _jc_java_nio_channels_Channels$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_Channels$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_java_nio_channels_Channels$method$newChannel$fbbca15d3c46a96a(_jc_env *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_nio_channels_Channels$method$newChannel$17120b72e13cdb59(_jc_env *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_nio_channels_Channels$method$newInputStream$a1eabc144c1b09d2(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_java_nio_channels_Channels$method$newOutputStream$eceb5d0d6e4ea2bb(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Reader$object *_jc_java_nio_channels_Channels$method$newReader$573210d7faf94df5(_jc_env *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Reader$object *_jc_java_nio_channels_Channels$method$newReader$30328f08f38f28d8(_jc_env *, struct _jc_object *, struct _jc_java_nio_charset_CharsetDecoder$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_io_Writer$object *_jc_java_nio_channels_Channels$method$newWriter$357027cb5c7e4756(_jc_env *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Writer$object *_jc_java_nio_channels_Channels$method$newWriter$e122b7c65d603cb2(_jc_env *, struct _jc_object *, struct _jc_java_nio_charset_CharsetEncoder$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_Channels$vmethods {
};

// Vtable
struct _jc_java_nio_channels_Channels$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Channels$vmethods	java_nio_channels_Channels;
};

// Vtype
struct _jc_java_nio_channels_Channels$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Channels$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Channels$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Channels$refs {
    _jc_java_nio_channels_Channels$sub_refs	java_nio_channels_Channels;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Channels$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Channels$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Channels$sub_nonrefs	java_nio_channels_Channels;
};

// Object instance structure
struct _jc_java_nio_channels_Channels$object {
	_jc_java_nio_channels_Channels$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Channels$vtype	*vtype;
	_jc_java_nio_channels_Channels$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Channels$vtype _jc_java_nio_channels_Channels$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Channels, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Channels$class_object;

#endif	/* _JC_java_nio_channels_Channels_H_ */
